registerNodeProcessors method

  1. @ToBeDeprecated('Use registerNodeProcessors2 instead')
void registerNodeProcessors(
  1. RuleVisitorRegistry registry,
  2. RuleContext context
)

Registers node processors in the given registry.

The node processors may use the provided context to access information that is not available from the AST nodes or their associated elements.

Implementation

@ToBeDeprecated('Use registerNodeProcessors2 instead')
void registerNodeProcessors(
  RuleVisitorRegistry registry,
  RuleContext context,
) {}