registerNodeProcessors2 method

  1. @experimental
void registerNodeProcessors2(
  1. RuleVisitorRegistry2 registry,
  2. RuleContext context
)

Registers node processors in the given registry.

The node processors may use the provided context to access information that is not available from the AST nodes or their associated elements.

Implementation

@experimental
void registerNodeProcessors2(
  RuleVisitorRegistry2 registry,
  RuleContext context,
) {}