PubspecEnvironment class abstract

Representation of an environment section in a pubspec file.

Example of an environment:

environment:
  sdk: '>=2.12.0 <4.0.0'
  flutter: ^3.3.10
Implemented types

Constructors

PubspecEnvironment()

Properties

flutter → PubspecEntry?
The flutter section, if specified.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdk → PubspecEntry?
The (Dart) sdk section, if specified.
no setter
token → PubspecNode
The node for this section's key.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited