PubspecHost class abstract

A section describing where a package is hosted in a custom package repository.

Implemented types

Constructors

PubspecHost()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isShortForm → bool
True, if short-form for writing hosted-dependencies was used.
no setter
name → PubspecEntry?
The name of the package at the package repository.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → PubspecNode
The node for this section's key.
no setterinherited
url → PubspecEntry?
The URL of the package repository.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited