RuleState.testing constructor

const RuleState.testing({
  1. Version? since,
})

Initializes a state that marks an analysis rule as being tested internally.

Rules in this state are experimental, temporary, and have no stability guarantees. They're not limited to being used within the Dart SDK, but they're not recommended for general use.

Implementation

const RuleState.testing({this.since}) : _type = .testing, replacedBy = null;