isTesting property
bool
get
isTesting
Whether this state marks an analysis rule as being tested internally.
Implementation
bool get isTesting => _type == _RuleStateType.testing;
Whether this state marks an analysis rule as being tested internally.
bool get isTesting => _type == _RuleStateType.testing;