sortUnnamedConstructorsFirst property
bool
get
sortUnnamedConstructorsFirst
Whether unnamed constructors should be sorted before named constructors.
Implementation
bool get sortUnnamedConstructorsFirst;
Whether unnamed constructors should be sorted before named constructors.
bool get sortUnnamedConstructorsFirst;