FragmentDeclarationResult class abstract

The declaration of a Fragment.

Constructors

FragmentDeclarationResult()

Properties

fragment → Fragment
The Fragment that this object describes.
no setter
hashCode → int
The hash code for this object.
no setterinherited
node → AstNode
The node that declares the fragment. Depending on whether it is returned from ResolvedLibraryResult or ParsedLibraryResult it might be resolved or just parsed.
no setter
parsedUnit → ParsedUnitResult?
If this declaration is returned from ParsedLibraryResult, the parsed unit that contains the node. Otherwise null.
no setter
resolvedUnit → ResolvedUnitResult?
If this declaration is returned from ResolvedLibraryResult, the resolved unit that contains the node. Otherwise null.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited