LibraryElementResult class abstract

The result of building the element model for a library.

Clients may not extend, implement or mix-in this class.

Implemented types

Constructors

LibraryElementResult()

Properties

element → LibraryElement
The element representing the library.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited