getFragmentDeclaration2 abstract method

  1. @experimental
FragmentDeclarationResult? getFragmentDeclaration2(
  1. Fragment fragment
)

Returns the declaration of the fragment in the V2 AST view.

Returns null if the fragment is synthetic.

Throws ArgumentError if the fragment is not defined in this library.

Implementation

@experimental
FragmentDeclarationResult? getFragmentDeclaration2(Fragment fragment);