ResolvedLibraryResult class abstract

The result of building resolved AST(s) for the whole library.

Clients may not extend, implement or mix-in this class.

Implemented types

Constructors

ResolvedLibraryResult()

Properties

element → LibraryElement
The element representing this library.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → AnalysisSession
Return the session used to compute this result.
no setterinherited
typeProvider → TypeProvider
The type provider used when resolving the library.
no setter
units → List<ResolvedUnitResult>
The resolved units of the library.
no setteroverride

Methods

getFragmentDeclaration(Fragment fragment) → FragmentDeclarationResult?
Returns the declaration of the fragment.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
unitWithPath(String path) → ResolvedUnitResult?
Return the resolved unit corresponding to the path, or null if there is no such unit.

Operators

operator ==(Object other) → bool
The equality operator.
inherited