ResolvedUnitResult class abstract

The result of building a resolved AST for a single file. The errors returned include both syntactic and semantic errors.

Clients may not extend, implement or mix-in this class.

Implemented types

Constructors

ResolvedUnitResult()

Properties

analysisOptions → AnalysisOptions
The analysis options for this file.
no setterinherited
content → String
The latest read content of file, the same that was used to compute other properties of this result.
no setterinherited
diagnostics → List<Diagnostic>
The diagnostics that were computed during analysis.
no setterinherited
errors → List<Diagnostic>
no setterinherited
exists → bool
Return true if the file exists.
no setter
file → File
The file resource.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isLibrary → bool
Whether the file is a library.
no setterinherited
isPart → bool
Whether the file is a part.
no setterinherited
libraryElement → LibraryElement
The element representing the library containing the compilation unit.
no setter
libraryFragment → LibraryFragment
The fragment corresponding to the unit.
no setter
lineInfo → LineInfo
Information about lines in the content.
no setterinherited
path → String
The absolute and normalized path of the file that was analyzed.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → AnalysisSession
Return the session used to compute this result.
no setterinherited
typeProvider → TypeProvider
The type provider used when resolving the compilation unit.
no setter
typeSystem → TypeSystem
The type system used when resolving the compilation unit.
no setter
unit → CompilationUnit
The parsed, unresolved compilation unit for the content.
no setterinherited
uri → Uri
The absolute URI of the file that was analyzed.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited