target property
The expression computing the object defining the property being accessed,
or null if this property access is part of a cascade expression.
Use realTarget to get the target independent of whether this is part of a cascade expression.
Implementation
@ToBeDeprecated('Use target2 instead.')
Expression? get target;