argumentExpression property
The expression that computes the value for this argument.
Implementation
@ToBeDeprecated('Use argumentExpression2 instead.')
Expression get argumentExpression;
The expression that computes the value for this argument.
@ToBeDeprecated('Use argumentExpression2 instead.')
Expression get argumentExpression;