condition property
The condition that is being asserted to be true.
Implementation
@ToBeDeprecated('Use condition2 instead.')
Expression get condition;
The condition that is being asserted to be true.
@ToBeDeprecated('Use condition2 instead.')
Expression get condition;