message property
The message to report if the assertion fails, or null if no message was
supplied.
Implementation
@ToBeDeprecated('Use message2 instead.')
Expression? get message;
The message to report if the assertion fails, or null if no message was
supplied.
@ToBeDeprecated('Use message2 instead.')
Expression? get message;