leftHandSide property
The expression used to compute the left hand side.
Implementation
@ToBeDeprecated('Use leftHandSide2 instead.')
Expression get leftHandSide;
The expression used to compute the left hand side.
@ToBeDeprecated('Use leftHandSide2 instead.')
Expression get leftHandSide;