value property
Expression
get
value
The right-hand-side expression.
Concrete assignment kinds determine how this value contributes to the eventual write to target.
Implementation
Expression get value;
The right-hand-side expression.
Concrete assignment kinds determine how this value contributes to the eventual write to target.
Expression get value;