read property

ReadResolution? get read

The read operation, or null if the enclosing operation does not read, this target has not been resolved, or receiver evaluation prevents the access.

An unsuccessful access is represented by an invalid resolution rather than null.

Implementation

ReadResolution? get read;