accept2<E> abstract method
Use the given visitor to visit this node.
Returns the value returned by the visitor as a result of visiting this node.
Implementation
@experimental
E? accept2<E>(AstVisitor2<E> visitor);
Use the given visitor to visit this node.
Returns the value returned by the visitor as a result of visiting this node.
@experimental
E? accept2<E>(AstVisitor2<E> visitor);