childEntities property
An iterator that can be used to iterate through all the entities (either AST nodes or tokens) that make up the contents of this node, including doc comments but excluding other comments.
Implementation
@ToBeDeprecated('Use childEntities2 instead')
Iterable<SyntacticEntity> get childEntities;