childEntities2 property

  1. @experimental
Iterable<SyntacticEntity> get childEntities2

An iterator that can be used to iterate through all the entities (either AST nodes or tokens) that make up the contents of this node, including doc comments but excluding other comments.

Implementation

@experimental
Iterable<SyntacticEntity> get childEntities2;