parent2 property

  1. @experimental
AstNode? get parent2

Returns this node's parent node, or null if this node is the root of an AST structure.

Note that the relationship between an AST node and its parent node may change over the lifetime of a node.

Implementation

@experimental
AstNode? get parent2;