root2 property
The node at the root of this node's AST structure.
Note that this method's performance is linear with respect to the depth of the node in the AST structure (O(depth)).
Implementation
@experimental
AstNode get root2;
The node at the root of this node's AST structure.
Note that this method's performance is linear with respect to the depth of the node in the AST structure (O(depth)).
@experimental
AstNode get root2;