thisOrAncestorMatching<E extends AstNode> abstract method
- @ToBeDeprecated('Use thisOrAncestorMatching2 instead')
Returns either this node or the most immediate ancestor of this node for
which the predicate returns true, or null if there's no such node.
Implementation
@ToBeDeprecated('Use thisOrAncestorMatching2 instead')
E? thisOrAncestorMatching<E extends AstNode>(
bool Function(AstNode) predicate,
);