thisOrAncestorMatching2<E extends AstNode> abstract method

  1. @experimental
E? thisOrAncestorMatching2<E extends AstNode>(
  1. bool predicate(
    1. AstNode
    )
)

Returns either this node or the most immediate ancestor of this node for which the predicate returns true, or null if there's no such node.

Implementation

@experimental
E? thisOrAncestorMatching2<E extends AstNode>(
  bool Function(AstNode) predicate,
);