thisOrAncestorOfType<E extends AstNode> abstract method

  1. @ToBeDeprecated('Use thisOrAncestorOfType2 instead')
E? thisOrAncestorOfType<E extends AstNode>()

Returns either this node or the most immediate ancestor of this node that has the given type, or null if there's no such node.

Implementation

@ToBeDeprecated('Use thisOrAncestorOfType2 instead')
E? thisOrAncestorOfType<E extends AstNode>();