visitChildren abstract method
Use the given visitor to visit all of the children of this node.
The children are visited in lexical order.
Implementation
@ToBeDeprecated('Use visitChildren2 instead')
void visitChildren(AstVisitor visitor);
Use the given visitor to visit all of the children of this node.
The children are visited in lexical order.
@ToBeDeprecated('Use visitChildren2 instead')
void visitChildren(AstVisitor visitor);