visitChildren2 abstract method
Use the given visitor to visit all of the children of this node.
The children are visited in lexical order.
Implementation
@experimental
void visitChildren2(AstVisitor2 visitor);
Use the given visitor to visit all of the children of this node.
The children are visited in lexical order.
@experimental
void visitChildren2(AstVisitor2 visitor);