write property
IndexWriteResolution?
get
write
The write operation, or null if this target has not been resolved or
the cascade target cannot complete.
Implementation
IndexWriteResolution? get write;
The write operation, or null if this target has not been resolved or
the cascade target cannot complete.
IndexWriteResolution? get write;