element property

Element? get element

The element exported under name, or null if there is no such element.

This is the element in the ordinary namespace entry, which includes getters, functions, variables, classes, mixins, and type aliases.

Implementation

Element? get element;