condition property
The condition used to determine which of the expressions is executed next.
Implementation
@ToBeDeprecated('Use condition2 instead.')
Expression get condition;
The condition used to determine which of the expressions is executed next.
@ToBeDeprecated('Use condition2 instead.')
Expression get condition;