elseExpression property
The expression that is executed if the condition evaluates to false.
Implementation
@ToBeDeprecated('Use elseExpression2 instead.')
Expression get elseExpression;
The expression that is executed if the condition evaluates to false.
@ToBeDeprecated('Use elseExpression2 instead.')
Expression get elseExpression;