thenExpression property
The expression that is executed if the condition evaluates to true.
Implementation
@ToBeDeprecated('Use thenExpression2 instead.')
Expression get thenExpression;
The expression that is executed if the condition evaluates to true.
@ToBeDeprecated('Use thenExpression2 instead.')
Expression get thenExpression;