errorRange property

SourceRange get errorRange

The offset and length to use as an error range for this constructor declaration, accounting for named and unnamed constructors.

Implementation

SourceRange get errorRange;