expression property
The expression computing the value to which the field is initialized.
Implementation
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;
The expression computing the value to which the field is initialized.
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;