fieldElement property
The field being initialized, or null if the AST structure hasn't been
resolved or if the field couldn't be resolved.
Implementation
@experimental
FieldElement? get fieldElement;
The field being initialized, or null if the AST structure hasn't been
resolved or if the field couldn't be resolved.
@experimental
FieldElement? get fieldElement;