element property
ConstructorElement?
get
element
The element associated with the referenced constructor based on static type information.
This is the constructor element after applying any explicit or inferred type arguments. Use ConstructorElement.baseElement to access the declaration element.
Returns null if the AST structure hasn't been resolved or if the
constructor couldn't be resolved.
Implementation
ConstructorElement? get element;