An override to force resolution to choose a member from a specific extension.
extensionOverride ::=
[Identifier] [TypeArgumentList]? [ArgumentList]
- Implemented types
- Implementers
- Annotations
-
- @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')
- @experimental
Properties
- argumentList → ArgumentList
-
The list of arguments to the override.
no setter
- beginToken → Token
-
The first token included in this node's source range.
no setterinherited
-
childEntities
→ Iterable<
SyntacticEntity> -
An iterator that can be used to iterate through all the entities (either
AST nodes or tokens) that make up the contents of this node, including doc
comments but excluding other comments.
no setterinherited
-
childEntities2
→ Iterable<
SyntacticEntity> -
An iterator that can be used to iterate through all the entities (either
AST nodes or tokens) that make up the contents of this node, including doc
comments but excluding other comments.
no setterinherited
- element → ExtensionElement
-
The extension that resolution will use to resolve member references.
no setter
- end → int
-
The offset of the character immediately following the last character of
this node's source range.
no setterinherited
- endToken → Token
-
The last token included in this node's source range.
no setterinherited
- extendedType → DartType?
-
The actual type extended by this override, produced by applying
typeArgumentTypes to the generic type extended by the extension, or
nullif the AST structure hasn't been resolved.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- importPrefix → ImportPrefixReference?
-
The optional import prefix before name.
no setter
- isNullAware → bool
-
Whether this override is null aware (as opposed to non-null).
no setter
- isSynthetic → bool
-
Whether this node is a synthetic node.
no setterinherited
- length → int
-
Return the number of characters in the syntactic entity's source range.
no setterinherited
- name → Token
-
The name of the extension being selected.
no setter
- offset → int
-
Return the offset from the beginning of the file to the first character in
the syntactic entity.
no setterinherited
- parent → AstNode?
-
Returns this node's parent node, or
nullif this node is the root of an AST structure.no setterinherited - parent2 → AstNode?
-
Returns this node's parent node, or
nullif this node is the root of an AST structure.no setterinherited - root → AstNode
-
The node at the root of this node's AST structure.
no setterinherited
- root2 → AstNode
-
The node at the root of this node's AST structure.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRange → SourceRange
-
Returns a SourceRange object describing the range of characters spanned
by this syntactic entity.
no setterinherited
- typeArguments → TypeArgumentList?
-
The type arguments to be applied to the extension, or
nullif there are no type arguments.no setter -
typeArgumentTypes
→ List<
DartType> ? -
The actual type arguments to be applied to the extension, either
explicitly specified in typeArguments, or inferred, or
nullif the AST structure hasn't been resolved.no setter
Methods
-
accept<
E> (AstVisitor< E> visitor) → E? -
Use the given
visitorto visit this node.inherited -
accept2<
E> (AstVisitor2< E> visitor) → E? -
Use the given
visitorto visit this node.inherited -
findPrevious(
Token target) → Token? -
Returns the token before
target, ornullif it can't be found.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
thisOrAncestorMatching<
E extends AstNode> (bool predicate(AstNode)) → E? -
Returns either this node or the most immediate ancestor of this node for
which the
predicatereturnstrue, ornullif there's no such node.inherited -
thisOrAncestorMatching2<
E extends AstNode> (bool predicate(AstNode)) → E? -
Returns either this node or the most immediate ancestor of this node for
which the
predicatereturnstrue, ornullif there's no such node.inherited -
thisOrAncestorOfType<
E extends AstNode> () → E? -
Returns either this node or the most immediate ancestor of this node that
has the given type, or
nullif there's no such node.inherited -
thisOrAncestorOfType2<
E extends AstNode> () → E? -
Returns either this node or the most immediate ancestor of this node that
has the given type, or
nullif there's no such node.inherited -
toSource(
) → String -
Returns a textual description of this node in a form approximating valid
source.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
AstVisitor visitor) → void -
Use the given
visitorto visit all of the children of this node.inherited -
visitChildren2(
AstVisitor2 visitor) → void -
Use the given
visitorto visit all of the children of this node.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited