condition property
The condition used to determine when to terminate the loop, or null if
there's no condition.
Implementation
@ToBeDeprecated('Use condition2 instead.')
Expression? get condition;
The condition used to determine when to terminate the loop, or null if
there's no condition.
@ToBeDeprecated('Use condition2 instead.')
Expression? get condition;