condition2 property
The condition used to determine when to terminate the loop, or null if
there's no condition.
Implementation
@experimental
Expression? get condition2;
The condition used to determine when to terminate the loop, or null if
there's no condition.
@experimental
Expression? get condition2;