The formal parameter list of a method declaration, function declaration, or function type alias.
Required positional parameters are represented by requiredPositionalFormalParameters. Optional positional or named parameters are represented by delimitedFormalParameters, whose DelimitedFormalParameters.isNamed getter identifies the form of the delimited group.
The compatibility parameters getter projects both structural positions as a single, fixed-length list.
formalParameterList ::= '(' ')' | '(' normalFormalParameters (',' optionalFormalParameters)? ')' | '(' optionalFormalParameters ')'
normalFormalParameters ::= FormalParameter (',' FormalParameter)*
optionalFormalParameters ::= optionalPositionalFormalParameters | namedFormalParameters
optionalPositionalFormalParameters ::= '[' FormalParameter (',' FormalParameter)* ']'
namedFormalParameters ::= '{' FormalParameter (',' FormalParameter)* '}'
- Implemented types
- Implementers
- Annotations
-
- @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')
Properties
- beginToken → Token
-
The first token included in this node's source range.
no setterinherited
-
childEntities
→ Iterable<
SyntacticEntity> -
An iterator that can be used to iterate through all the entities (either
AST nodes or tokens) that make up the contents of this node, including doc
comments but excluding other comments.
no setterinherited
-
childEntities2
→ Iterable<
SyntacticEntity> -
An iterator that can be used to iterate through all the entities (either
AST nodes or tokens) that make up the contents of this node, including doc
comments but excluding other comments.
no setterinherited
- delimitedFormalParameters → DelimitedFormalParameters?
-
The optional positional or named formal parameters, or
nullif there are no delimited formal parameters.no setter - end → int
-
The offset of the character immediately following the last character of
this node's source range.
no setterinherited
- endToken → Token
-
The last token included in this node's source range.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSynthetic → bool
-
Whether this node is a synthetic node.
no setterinherited
- leftDelimiter → Token?
-
The left square bracket ('[') or left curly brace ('{') introducing the
optional or named parameters, or
nullif there are neither optional nor named parameters.no setter - leftParenthesis → Token
-
The left parenthesis.
no setter
- length → int
-
Return the number of characters in the syntactic entity's source range.
no setterinherited
- offset → int
-
Return the offset from the beginning of the file to the first character in
the syntactic entity.
no setterinherited
-
parameterFragments
→ List<
FormalParameterFragment?> -
A list containing the fragments representing the parameters in this list.
no setter
-
parameters
→ NodeList<
FormalParameter> -
The parameters associated with the method.
no setter
- parent → AstNode?
-
Returns this node's parent node, or
nullif this node is the root of an AST structure.no setterinherited - parent2 → AstNode?
-
Returns this node's parent node, or
nullif this node is the root of an AST structure.no setterinherited -
requiredPositionalFormalParameters
→ NodeList<
FormalParameter> -
The required positional formal parameters at the start of this list.
no setter
- rightDelimiter → Token?
-
The right square bracket (']') or right curly brace ('}') terminating the
optional or named parameters, or
nullif there are neither optional nor named parameters.no setter - rightParenthesis → Token
-
The right parenthesis.
no setter
- root → AstNode
-
The node at the root of this node's AST structure.
no setterinherited
- root2 → AstNode
-
The node at the root of this node's AST structure.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRange → SourceRange
-
Returns a SourceRange object describing the range of characters spanned
by this syntactic entity.
no setterinherited
Methods
-
accept<
E> (AstVisitor< E> visitor) → E? -
Use the given
visitorto visit this node.inherited -
accept2<
E> (AstVisitor2< E> visitor) → E? -
Use the given
visitorto visit this node.inherited -
findPrevious(
Token target) → Token? -
Returns the token before
target, ornullif it can't be found.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
thisOrAncestorMatching<
E extends AstNode> (bool predicate(AstNode)) → E? -
Returns either this node or the most immediate ancestor of this node for
which the
predicatereturnstrue, ornullif there's no such node.inherited -
thisOrAncestorMatching2<
E extends AstNode> (bool predicate(AstNode)) → E? -
Returns either this node or the most immediate ancestor of this node for
which the
predicatereturnstrue, ornullif there's no such node.inherited -
thisOrAncestorOfType<
E extends AstNode> () → E? -
Returns either this node or the most immediate ancestor of this node that
has the given type, or
nullif there's no such node.inherited -
thisOrAncestorOfType2<
E extends AstNode> () → E? -
Returns either this node or the most immediate ancestor of this node that
has the given type, or
nullif there's no such node.inherited -
toSource(
) → String -
Returns a textual description of this node in a form approximating valid
source.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
AstVisitor visitor) → void -
Use the given
visitorto visit all of the children of this node.inherited -
visitChildren2(
AstVisitor2 visitor) → void -
Use the given
visitorto visit all of the children of this node.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited