lookupPromotedThisType abstract method
Queries the promoted type of this at the given offset.
The offset is relative to the beginning of the source file, but must refer to a location within the function body in order for the response to be accurate.
The bodies of local functions and function literals cannot be queried directly; the query must be made using the enclosing non-local function body.
If this has not been promoted at the given offset, or is not meaningful
at the given offset, null is returned.
Throws an exception if resolution hasn't been performed, or if the query is made on the body of a local function or function literal.
Implementation
@experimental
DartType? lookupPromotedThisType({required int offset});