isComplete property

bool get isComplete

Whether this function declaration is complete for augmentation purposes.

A function declaration is complete if it is external or has a body.

Implementation

bool get isComplete;