A tear-off of call through the core Function interface.
The core Function interface exposes call without selecting a declaration
element or providing an exact function signature. The type is the static
type produced by the tear-off. It can be the core Function interface or a
type parameter whose bound resolves to that interface.
- Implemented types
- Implementers
- Annotations
-
- @experimental
- @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited