resolution property

InvocationResolution? get resolution

The resolution of this invocation.

This is null if the invocation has not been resolved, or if evaluation of its receiver cannot complete and therefore no invocation occurs.

Implementation

InvocationResolution? get resolution;