typeArguments property
TypeArgumentList?
get
typeArguments
The explicitly written type arguments, or null if none were written.
Implementation
TypeArgumentList? get typeArguments;
The explicitly written type arguments, or null if none were written.
TypeArgumentList? get typeArguments;