hiddenNames property
The list of names from the library that are hidden by this combinator.
Implementation
@ToBeDeprecated('Use names instead.')
NodeList<SimpleIdentifier> get hiddenNames;
The list of names from the library that are hidden by this combinator.
@ToBeDeprecated('Use names instead.')
NodeList<SimpleIdentifier> get hiddenNames;