elseElement property
The statement that is executed if the condition evaluates to false, or
null if there's no else statement.
Implementation
@ToBeDeprecated('Use elseElement2 instead.')
CollectionElement? get elseElement;
The statement that is executed if the condition evaluates to false, or
null if there's no else statement.
@ToBeDeprecated('Use elseElement2 instead.')
CollectionElement? get elseElement;