thenElement property
The statement that is executed if the condition evaluates to true.
Implementation
@ToBeDeprecated('Use thenElement2 instead.')
CollectionElement get thenElement;
The statement that is executed if the condition evaluates to true.
@ToBeDeprecated('Use thenElement2 instead.')
CollectionElement get thenElement;