rightOperand property
Expression
get
rightOperand
The expression evaluated if the left operand evaluates to null.
Implementation
Expression get rightOperand;
The expression evaluated if the left operand evaluates to null.
Expression get rightOperand;