expression property
The expression used to either determine which of the statements is
executed next or to compute the value matched against the pattern in the
case clause.
Implementation
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;