expression property
The expression from which a call method is being referenced.
Implementation
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;
The expression from which a call method is being referenced.
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;