operand property
Expression
get
operand
The callable object from which the method is extracted.
Implementation
Expression get operand;
The callable object from which the method is extracted.
Expression get operand;