target property
AssignmentTarget
get
target
The location that is read and then written by this operation.
Implementation
AssignmentTarget get target;
The location that is read and then written by this operation.
AssignmentTarget get target;