IndexAssignmentTarget class abstract final

An indexed location used as an assignment destination.

This migration slice supports ordinary non-cascade direct, compound, and if-null assignments, and prefix and postfix increment and decrement. Cascade indexing remains on its existing AST shape.

Implemented types
Implementers
Annotations
  • @experimental
  • @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')

Properties

beginToken Token
The first token included in this node's source range.
no setterinherited
childEntities Iterable<SyntacticEntity>
An iterator that can be used to iterate through all the entities (either AST nodes or tokens) that make up the contents of this node, including doc comments but excluding other comments.
no setterinherited
childEntities2 Iterable<SyntacticEntity>
An iterator that can be used to iterate through all the entities (either AST nodes or tokens) that make up the contents of this node, including doc comments but excluding other comments.
no setterinherited
end int
The offset of the character immediately following the last character of this node's source range.
no setterinherited
endToken Token
The last token included in this node's source range.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasRead bool
Whether the enclosing operation reads the target's current value before writing a new value.
no setterinherited
index Expression
The expression used to compute the index.
no setter
isSynthetic bool
Whether this node is a synthetic node.
no setterinherited
leftBracket Token
The left square bracket.
no setter
length int
Return the number of characters in the syntactic entity's source range.
no setterinherited
offset int
Return the offset from the beginning of the file to the first character in the syntactic entity.
no setterinherited
parent AstNode?
Returns this node's parent node, or null if this node is the root of an AST structure.
no setterinherited
parent2 AstNode?
Returns this node's parent node, or null if this node is the root of an AST structure.
no setterinherited
question Token?
The question mark before the left square bracket, or null if this target isn't null aware.
no setter
read IndexReadResolution?
The read operation, or null if the enclosing operation does not read, this target has not been resolved, or receiver evaluation prevents the index operation.
no setter
receiver Expression
The expression whose value is indexed.
no setter
rightBracket Token
The right square bracket.
no setter
root AstNode
The node at the root of this node's AST structure.
no setterinherited
root2 AstNode
The node at the root of this node's AST structure.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceRange SourceRange
Returns a SourceRange object describing the range of characters spanned by this syntactic entity.
no setterinherited
write IndexWriteResolution?
The write operation, or null if the enclosing operation does not write, this target has not been resolved, or receiver evaluation prevents the index operation.
no setter

Methods

accept<E>(AstVisitor<E> visitor) → E?
Use the given visitor to visit this node.
inherited
accept2<E>(AstVisitor2<E> visitor) → E?
Use the given visitor to visit this node.
inherited
findPrevious(Token target) Token?
Returns the token before target, or null if it can't be found.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
thisOrAncestorMatching<E extends AstNode>(bool predicate(AstNode)) → E?
Returns either this node or the most immediate ancestor of this node for which the predicate returns true, or null if there's no such node.
inherited
thisOrAncestorMatching2<E extends AstNode>(bool predicate(AstNode)) → E?
Returns either this node or the most immediate ancestor of this node for which the predicate returns true, or null if there's no such node.
inherited
thisOrAncestorOfType<E extends AstNode>() → E?
Returns either this node or the most immediate ancestor of this node that has the given type, or null if there's no such node.
inherited
thisOrAncestorOfType2<E extends AstNode>() → E?
Returns either this node or the most immediate ancestor of this node that has the given type, or null if there's no such node.
inherited
toSource() String
Returns a textual description of this node in a form approximating valid source.
inherited
toString() String
A string representation of this object.
inherited
visitChildren(AstVisitor visitor) → void
Use the given visitor to visit all of the children of this node.
inherited
visitChildren2(AstVisitor2 visitor) → void
Use the given visitor to visit all of the children of this node.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited