write property

The write operation, or null if the enclosing operation does not write, this target has not been resolved, or receiver evaluation prevents the index operation.

Implementation

IndexWriteResolution? get write;