realTarget property
The expression used to compute the object being indexed.
If this index expression isn't part of a cascade expression, then this is the same as target. If this index expression is part of a cascade expression, then the target expression stored with the cascade expression is returned.
Implementation
@ToBeDeprecated('Use realTarget2 instead.')
Expression get realTarget;