realTarget2 property

  1. @experimental
Expression get realTarget2

The expression used to compute the object being indexed.

If this index expression isn't part of a cascade expression, then this is the same as target2. If this index expression is part of a cascade expression, then the target expression stored with the cascade expression is returned.

Implementation

@experimental
Expression get realTarget2;