question property
Token?
get
question
The question mark before the left square bracket, or null if this
expression isn't null aware.
Implementation
Token? get question;
The question mark before the left square bracket, or null if this
expression isn't null aware.
Token? get question;