body property
InstanceDeclarationBody
get
body
The body containing the members explicitly written by this declaration.
Implementation
InstanceDeclarationBody get body;
The body containing the members explicitly written by this declaration.
InstanceDeclarationBody get body;