typeParameters property
TypeParameterList?
get
typeParameters
The type parameters, or null if there are none.
Implementation
TypeParameterList? get typeParameters;
The type parameters, or null if there are none.
TypeParameterList? get typeParameters;