parseDoubleValue abstract method

double? parseDoubleValue({
  1. required bool negated,
})

Returns the double value represented by this literal, or null if the value can't be represented exactly as a finite double.

If negated is true, returns the value of the expression formed by immediately preceding this literal with a unary minus. In particular, negating a literal whose value is zero produces negative zero.

Implementation

double? parseDoubleValue({required bool negated});