expression property
The expression to be evaluated for the value to be converted into a string.
Implementation
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;
The expression to be evaluated for the value to be converted into a string.
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;