write property
The write operation, or null if this target has not been resolved
or receiver evaluation prevents the access.
An unsuccessful access is represented by an invalid resolution rather
than null. A non-null resolution does not guarantee runtime execution;
for example, an if-null assignment writes conditionally.
Implementation
@override
InvalidWriteResolution? get write;