An unsuccessful index read resolution.
- Implemented types
- Implementers
- Annotations
-
- @experimental
- @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- recovery → ValidIndexReadResolution?
-
A complete hypothetical valid resolution used for recovery.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DartType
-
The type produced by
operator [].no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited