key property
The expression computing the key of the entry to be matched.
Implementation
@ToBeDeprecated('Use key2 instead.')
Expression get key;
The expression computing the key of the entry to be matched.
@ToBeDeprecated('Use key2 instead.')
Expression get key;