isAbstract property
Whether this method is declared to be an abstract method.
Implementation
@Deprecated('Use isComplete instead')
bool get isAbstract;
Whether this method is declared to be an abstract method.
@Deprecated('Use isComplete instead')
bool get isAbstract;