isComplete property

bool get isComplete

Whether this method declaration is complete for augmentation purposes.

A method declaration is complete if it is external or has a body.

Implementation

bool get isComplete;