MethodDeclaration2 class abstract final

A method declaration in an instance declaration body.

Implemented types
Implementers
Annotations
  • @experimental
  • @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')

Properties

augmentKeyword Token?
The augment keyword, or null if there is no augment keyword.
no setter
beginToken Token
The first token included in this node's source range.
no setterinherited
body FunctionBody
The body of the method.
no setter
childEntities Iterable<SyntacticEntity>
An iterator that can be used to iterate through all the entities (either AST nodes or tokens) that make up the contents of this node, including doc comments but excluding other comments.
no setterinherited
childEntities2 Iterable<SyntacticEntity>
An iterator that can be used to iterate through all the entities (either AST nodes or tokens) that make up the contents of this node, including doc comments but excluding other comments.
no setterinherited
declaredFragment MethodFragment?
The fragment associated with this node, or null if there is no associated fragment or if the AST structure hasn't been resolved.
no setteroverride
documentationComment Comment?
The documentation comment associated with this node, or null if this node doesn't have a documentation comment associated with it.
no setterinherited
end int
The offset of the character immediately following the last character of this node's source range.
no setterinherited
endToken Token
The last token included in this node's source range.
no setterinherited
externalKeyword Token?
The external keyword, or null if this isn't an external method.
no setter
firstTokenAfterCommentAndMetadata Token
The first token following the comment and metadata.
no setterinherited
formalParameters FormalParameterList
The formal parameters of the method.
no setter
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
Whether this declaration is complete for augmentation purposes.
no setter
isSynthetic bool
Whether this node is a synthetic node.
no setterinherited
length int
Return the number of characters in the syntactic entity's source range.
no setterinherited
metadata NodeList<Annotation>
The annotations associated with this node.
no setterinherited
name Token
The name of the method.
no setter
offset int
Return the offset from the beginning of the file to the first character in the syntactic entity.
no setterinherited
parent AstNode?
Returns this node's parent node, or null if this node is the root of an AST structure.
no setterinherited
parent2 AstNode?
Returns this node's parent node, or null if this node is the root of an AST structure.
no setterinherited
returnType TypeAnnotation?
The return type of the method, or null if no return type was declared.
no setter
root AstNode
The node at the root of this node's AST structure.
no setterinherited
root2 AstNode
The node at the root of this node's AST structure.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortedCommentAndAnnotations List<AstNode>
A list containing the comment and annotations associated with this node, sorted in lexical order.
no setterinherited
sourceRange SourceRange
Returns a SourceRange object describing the range of characters spanned by this syntactic entity.
no setterinherited
staticKeyword Token?
The static keyword, or null if this isn't a static method.
no setter
typeParameters TypeParameterList?
The type parameters of the method, or null if the method isn't generic.
no setter

Methods

accept<E>(AstVisitor<E> visitor) → E?
Use the given visitor to visit this node.
inherited
accept2<E>(AstVisitor2<E> visitor) → E?
Use the given visitor to visit this node.
inherited
findPrevious(Token target) Token?
Returns the token before target, or null if it can't be found.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
thisOrAncestorMatching<E extends AstNode>(bool predicate(AstNode)) → E?
Returns either this node or the most immediate ancestor of this node for which the predicate returns true, or null if there's no such node.
inherited
thisOrAncestorMatching2<E extends AstNode>(bool predicate(AstNode)) → E?
Returns either this node or the most immediate ancestor of this node for which the predicate returns true, or null if there's no such node.
inherited
thisOrAncestorOfType<E extends AstNode>() → E?
Returns either this node or the most immediate ancestor of this node that has the given type, or null if there's no such node.
inherited
thisOrAncestorOfType2<E extends AstNode>() → E?
Returns either this node or the most immediate ancestor of this node that has the given type, or null if there's no such node.
inherited
toSource() String
Returns a textual description of this node in a form approximating valid source.
inherited
toString() String
A string representation of this object.
inherited
visitChildren(AstVisitor visitor) → void
Use the given visitor to visit all of the children of this node.
inherited
visitChildren2(AstVisitor2 visitor) → void
Use the given visitor to visit all of the children of this node.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited