declaredFragment property
The fragment associated with this node, or null if there is no
associated fragment or if the AST structure hasn't been resolved.
Implementation
@override
MethodFragment? get declaredFragment;
The fragment associated with this node, or null if there is no
associated fragment or if the AST structure hasn't been resolved.
@override
MethodFragment? get declaredFragment;