typeParameters property
TypeParameterList?
get
typeParameters
The type parameters of the method, or null if the method isn't generic.
Implementation
TypeParameterList? get typeParameters;
The type parameters of the method, or null if the method isn't generic.
TypeParameterList? get typeParameters;