realTarget2 property

  1. @experimental
Expression? get realTarget2

The expression used to compute the receiver of the invocation.

If this invocation isn't part of a cascade expression, then this is the same as target2. If this invocation is part of a cascade expression, then the target stored with the cascade expression is returned.

Implementation

@experimental
Expression? get realTarget2;