NamedReadResolution class abstract final

The resolution of a named read.

This resolution is used both by expressions that extract a property value and by assignments that need the target's current value, as in a compound assignment, an if-null assignment, or an increment or decrement.

Implementers
Annotations
  • @experimental
  • @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DartType
The static type of the value produced by the read.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited