type property

  1. @override
DartType? get type
override

The type being named, or null if the AST structure hasn't been resolved, or if this is part of the legacy constructor-reference projection.

Implementation

@override
DartType? get type;