NamedWriteResolutionWithElement class abstract final

A named write that was resolved to an element.

Implemented types
Implementers
Annotations
  • @experimental
  • @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')

Properties

acceptedType DartType
The type accepted by the write operation.
no setterinherited
element Element
The selected declaration, including any substitution for this occurrence, or null if the write does not select a declaration.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited