element property

  1. @override
Element get element
override

The selected declaration, including any substitution for this occurrence, or null if the write does not select a declaration.

Dynamic and invalid resolutions return null. Candidates and recovery elements are excluded.

Implementation

@override
Element get element;