accept abstract method
Use the given visitor to visit each of the nodes in this list.
Implementation
@ToBeDeprecated('Use accept2 instead.')
void accept(AstVisitor visitor);
Use the given visitor to visit each of the nodes in this list.
@ToBeDeprecated('Use accept2 instead.')
void accept(AstVisitor visitor);