accept2 abstract method
Use the given visitor to visit each of the nodes in this list.
Implementation
@experimental
void accept2(AstVisitor2 visitor);
Use the given visitor to visit each of the nodes in this list.
@experimental
void accept2(AstVisitor2 visitor);