operand property
Expression
get
operand
The expression whose value is asserted to be non-null.
Implementation
Expression get operand;
The expression whose value is asserted to be non-null.
Expression get operand;