value property
The expression computing the value that is associated with the element.
Implementation
@ToBeDeprecated('Use value2 instead.')
Expression get value;
The expression computing the value that is associated with the element.
@ToBeDeprecated('Use value2 instead.')
Expression get value;