element property

Element? get element

The selected declaration, including any substitution for this occurrence, or null if the read does not select a declaration.

Dynamic access, record-field reads, function call tear-offs, and invalid resolutions return null. Candidates and recovery elements are excluded.

Implementation

Element? get element;