type property
DartType
get
type
The static type of the value produced if the read executes.
Implementation
DartType get type;
The static type of the value produced if the read executes.
DartType get type;