operator property
Token
get
operator
The operator separating the receiver from the method name.
Implementation
Token get operator;
The operator separating the receiver from the method name.
Token get operator;