expression property
The expression computing the value to be returned, or null if no
explicit value was provided.
Implementation
@ToBeDeprecated('Use expression2 instead.')
Expression? get expression;
The expression computing the value to be returned, or null if no
explicit value was provided.
@ToBeDeprecated('Use expression2 instead.')
Expression? get expression;