elements property
The syntactic elements used to compute the elements of the set or map.
Implementation
@ToBeDeprecated('Use elements2 instead.')
NodeList<CollectionElement> get elements;
The syntactic elements used to compute the elements of the set or map.
@ToBeDeprecated('Use elements2 instead.')
NodeList<CollectionElement> get elements;