expression property
The expression used to compute the collection being spread.
Implementation
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;
The expression used to compute the collection being spread.
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;