constructorSelector property

  1. @experimental
ConstructorSelector? get constructorSelector

The selector of the constructor that is being invoked, or null if the unnamed constructor is being invoked.

Implementation

@experimental
ConstructorSelector? get constructorSelector;