expression property
The expression whose value is returned from the switch expression if the pattern matches.
Implementation
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;
The expression whose value is returned from the switch expression if the pattern matches.
@ToBeDeprecated('Use expression2 instead.')
Expression get expression;