guardedPattern property
GuardedPattern
get
guardedPattern
The refutable pattern that must match for the expression2 to be executed.
Implementation
GuardedPattern get guardedPattern;
The refutable pattern that must match for the expression2 to be executed.
GuardedPattern get guardedPattern;