read property
NamedReadResolution?
get
read
The read operation, or null if the assignment does not read the target
or this target has not been resolved.
Implementation
NamedReadResolution? get read;
The read operation, or null if the assignment does not read the target
or this target has not been resolved.
NamedReadResolution? get read;