write property
NamedWriteResolution?
get
write
The write operation, or null if this target has not been resolved.
Implementation
NamedWriteResolution? get write;
The write operation, or null if this target has not been resolved.
NamedWriteResolution? get write;