ValidDotShorthandContextResolution class abstract final

A usable dot-shorthand context.

Implemented types
Implementers
Annotations
  • @experimental
  • @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')

Properties

contextType DartType
The contextual type supplied to the maximal dot-shorthand expression.
no setter
hashCode int
The hash code for this object.
no setterinherited
lookupType InterfaceType
The normalized interface type whose static namespace is searched.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited