initializer property

  1. @ToBeDeprecated('Use initializer2 instead.')
Expression? get initializer

The expression used to compute the initial value for the variable, or null if the initial value isn't specified.

Implementation

@ToBeDeprecated('Use initializer2 instead.')
Expression? get initializer;