condition property
The expression used to determine whether to execute the body of the loop.
Implementation
@ToBeDeprecated('Use condition2 instead.')
Expression get condition;
The expression used to determine whether to execute the body of the loop.
@ToBeDeprecated('Use condition2 instead.')
Expression get condition;