MdCodeBlockLine class final

A Markdown code block line found in a documentation comment.

Constructors

MdCodeBlockLine({required int offset, required int length})

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
The length of the fenced code block.
final
offset → int
The offset of the start of the code block, from the beginning of the compilation unit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited