SyntacticEntity class abstract

Interface representing a syntactic entity (either a token or an AST node) which has a location and extent in the source file.

Clients may not extend, implement or mix-in this class.

Implementers
Annotations
  • @AnalyzerPublicApi.new(message: 'exported by package:analyzer/dart/ast/syntactic_entity.dart')

Constructors

SyntacticEntity()

Properties

end → int
Return the offset from the beginning of the file to the character after the last character of the syntactic entity.
no setter
hashCode → int
The hash code for this object.
no setterinherited
length → int
Return the number of characters in the syntactic entity's source range.
no setter
offset → int
Return the offset from the beginning of the file to the first character in the syntactic entity.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceRange → SourceRange
Returns a SourceRange object describing the range of characters spanned by this syntactic entity.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited