lexeme property
String
get
lexeme
Return the lexeme that represents this token.
For StringTokens the lexeme includes the quotes, explicit escapes, etc.
Implementation
String get lexeme;
Return the lexeme that represents this token.
For StringTokens the lexeme includes the quotes, explicit escapes, etc.
String get lexeme;