DelegatingAstVisitor2<T> class
An AST visitor that will recursively visit all of the nodes in an AST structure. For each node that is visited, the corresponding visit method on one or more other visitors (the 'delegates') will be invoked.
For example, if an instance of this class is created with two delegates V1 and V2, and that instance is used to visit the expression 'x + 1', then the following visit methods will be invoked:
- V1.visitBinaryOperatorInvocation
- V2.visitBinaryOperatorInvocation
- V1.visitSimpleIdentifier
- V2.visitSimpleIdentifier
- V1.visitIntegerLiteral
- V2.visitIntegerLiteral
Clients may not extend, implement or mix-in this class.
- Inheritance
-
- Object
- UnifyingAstVisitor2<
T> - DelegatingAstVisitor2
- Annotations
-
- @experimental
Constructors
-
DelegatingAstVisitor2(Iterable<
AstVisitor2< delegates)T> > -
Initialize a newly created visitor to use each of the given delegate
visitors to visit the nodes of an AST structure.
const
Properties
-
delegates
→ Iterable<
AstVisitor2< T> > -
The delegates whose visit methods will be invoked.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitAdjacentStrings(
AdjacentStrings node) → T? -
inherited
-
visitAnnotation(
Annotation node) → T? -
inherited
-
visitAnonymousBlockBody(
AnonymousBlockBody node) → T? -
inherited
-
visitAnonymousExpressionBody(
AnonymousExpressionBody node) → T? -
inherited
-
visitAnonymousMethodInvocation(
AnonymousMethodInvocation node) → T? -
inherited
-
visitArgumentList(
ArgumentList node) → T? -
inherited
-
visitAsExpression(
AsExpression node) → T? -
inherited
-
visitAssertInitializer(
AssertInitializer node) → T? -
inherited
-
visitAssertStatement(
AssertStatement node) → T? -
inherited
-
visitAssignedVariablePattern(
AssignedVariablePattern node) → T? -
inherited
-
visitAssignmentExpression(
AssignmentExpression node) → T? -
inherited
-
visitAwaitExpression(
AwaitExpression node) → T? -
inherited
-
visitBinaryOperatorInvocation(
BinaryOperatorInvocation node) → T? -
inherited
-
visitBlock(
Block node) → T? -
inherited
-
visitBlockClassBody(
BlockClassBody node) → T? -
inherited
-
visitBlockEnumBody(
BlockEnumBody node) → T? -
inherited
-
visitBlockFunctionBody(
BlockFunctionBody node) → T? -
inherited
-
visitBooleanLiteral(
BooleanLiteral node) → T? -
inherited
-
visitBreakStatement(
BreakStatement node) → T? -
inherited
-
visitCascadeExpression(
CascadeExpression node) → T? -
inherited
-
visitCascadeIndexAssignmentTarget(
CascadeIndexAssignmentTarget node) → T? -
inherited
-
visitCascadeIndexExpression(
CascadeIndexExpression node) → T? -
inherited
-
visitCascadePropertyAssignmentTarget(
CascadePropertyAssignmentTarget node) → T? -
inherited
-
visitCascadePropertyExtraction(
CascadePropertyExtraction node) → T? -
inherited
-
visitCascadeSection(
CascadeSection node) → T? -
inherited
-
visitCaseClause(
CaseClause node) → T? -
inherited
-
visitCastPattern(
CastPattern node) → T? -
inherited
-
visitCatchClause(
CatchClause node) → T? -
inherited
-
visitCatchClauseParameter(
CatchClauseParameter node) → T? -
inherited
-
visitClassDeclaration(
ClassDeclaration node) → T? -
inherited
-
visitClassTypeAlias(
ClassTypeAlias node) → T? -
inherited
-
visitCombinatorName(
CombinatorName node) → T? -
inherited
-
visitComment(
Comment node) → T? -
inherited
-
visitCommentReference(
CommentReference node) → T? -
inherited
-
visitCompilationUnit(
CompilationUnit node) → T? -
inherited
-
visitCompoundAssignment(
CompoundAssignment node) → T? -
inherited
-
visitConditionalExpression(
ConditionalExpression node) → T? -
inherited
-
visitConfiguration(
Configuration node) → T? -
inherited
-
visitConstantPattern(
ConstantPattern node) → T? -
inherited
-
visitConstructorDeclaration(
ConstructorDeclaration node) → T? -
inherited
-
visitConstructorFieldInitializer(
ConstructorFieldInitializer node) → T? -
inherited
-
visitConstructorInvocation(
ConstructorInvocation node) → T? -
inherited
-
visitConstructorReference2(
ConstructorReference2 node) → T? -
inherited
-
visitConstructorSelector(
ConstructorSelector node) → T? -
inherited
-
visitConstructorTearOff(
ConstructorTearOff node) → T? -
inherited
-
visitConstructorTypeReference(
ConstructorTypeReference node) → T? -
inherited
-
visitContinueStatement(
ContinueStatement node) → T? -
inherited
-
visitDeclaredIdentifier(
DeclaredIdentifier node) → T? -
inherited
-
visitDeclaredVariablePattern(
DeclaredVariablePattern node) → T? -
inherited
-
visitDelimitedFormalParameters(
DelimitedFormalParameters node) → T? -
inherited
-
visitDirectAssignment(
DirectAssignment node) → T? -
inherited
-
visitDoStatement(
DoStatement node) → T? -
inherited
-
visitDotShorthandConstructorInvocation(
DotShorthandConstructorInvocation node) → T? -
inherited
-
visitDotShorthandInvocation(
DotShorthandInvocation node) → T? -
inherited
-
visitDotShorthandPropertyAccess(
DotShorthandPropertyAccess node) → T? -
inherited
-
visitDottedName(
DottedName node) → T? -
inherited
-
visitDoubleLiteral(
DoubleLiteral node) → T? -
inherited
-
visitEmptyClassBody(
EmptyClassBody node) → T? -
inherited
-
visitEmptyEnumBody(
EmptyEnumBody node) → T? -
inherited
-
visitEmptyFunctionBody(
EmptyFunctionBody node) → T? -
inherited
-
visitEmptyStatement(
EmptyStatement node) → T? -
inherited
-
visitEnumConstantArguments(
EnumConstantArguments node) → T? -
inherited
-
visitEnumConstantDeclaration(
EnumConstantDeclaration node) → T? -
inherited
-
visitEnumDeclaration(
EnumDeclaration node) → T? -
inherited
-
visitExportDirective(
ExportDirective node) → T? -
inherited
-
visitExpressionFunctionBody(
ExpressionFunctionBody node) → T? -
inherited
-
visitExpressionStatement(
ExpressionStatement node) → T? -
inherited
-
visitExtendsClause(
ExtendsClause node) → T? -
inherited
-
visitExtensionDeclaration(
ExtensionDeclaration node) → T? -
inherited
-
visitExtensionOnClause(
ExtensionOnClause node) → T? -
inherited
-
visitExtensionOverride(
ExtensionOverride node) → T? -
inherited
-
visitExtensionTypeDeclaration(
ExtensionTypeDeclaration node) → T? -
inherited
-
visitFieldDeclaration(
FieldDeclaration node) → T? -
inherited
-
visitFieldFormalParameter(
FieldFormalParameter node) → T? -
inherited
-
visitForEachPartsWithDeclaration(
ForEachPartsWithDeclaration node) → T? -
inherited
-
visitForEachPartsWithIdentifier(
ForEachPartsWithIdentifier node) → T? -
inherited
-
visitForEachPartsWithPattern(
ForEachPartsWithPattern node) → T? -
inherited
-
visitForElement(
ForElement node) → T? -
inherited
-
visitFormalParameterDefaultClause(
FormalParameterDefaultClause node) → T? -
inherited
-
visitFormalParameterList(
FormalParameterList node) → T? -
inherited
-
visitForPartsWithDeclarations(
ForPartsWithDeclarations node) → T? -
inherited
-
visitForPartsWithExpression(
ForPartsWithExpression node) → T? -
inherited
-
visitForPartsWithPattern(
ForPartsWithPattern node) → T? -
inherited
-
visitForStatement(
ForStatement node) → T? -
inherited
-
visitFunctionDeclaration(
FunctionDeclaration node) → T? -
inherited
-
visitFunctionDeclarationStatement(
FunctionDeclarationStatement node) → T? -
inherited
-
visitFunctionExpression(
FunctionExpression node) → T? -
inherited
-
visitFunctionExpressionInvocation(
FunctionExpressionInvocation node) → T? -
inherited
-
visitFunctionReference(
FunctionReference node) → T? -
inherited
-
visitFunctionTypeAlias(
FunctionTypeAlias node) → T? -
inherited
-
visitFunctionTypedFormalParameterSuffix(
FunctionTypedFormalParameterSuffix node) → T? -
inherited
-
visitGenericFunctionType(
GenericFunctionType node) → T? -
inherited
-
visitGenericTypeAlias(
GenericTypeAlias node) → T? -
inherited
-
visitGetterDeclaration(
GetterDeclaration node) → T? -
inherited
-
visitGuardedPattern(
GuardedPattern node) → T? -
inherited
-
visitHideCombinator(
HideCombinator node) → T? -
inherited
-
visitIfElement(
IfElement node) → T? -
inherited
-
visitIfNull(
IfNull node) → T? -
inherited
-
visitIfNullAssignment(
IfNullAssignment node) → T? -
inherited
-
visitIfStatement(
IfStatement node) → T? -
inherited
-
visitImplementsClause(
ImplementsClause node) → T? -
inherited
-
visitImplicitCallReference(
ImplicitCallReference node) → T? -
inherited
-
visitImportDirective(
ImportDirective node) → T? -
inherited
-
visitImportPrefixReference(
ImportPrefixReference node) → T? -
inherited
-
visitIndexAssignmentTarget(
IndexAssignmentTarget node) → T? -
inherited
-
visitIndexExpression(
IndexExpression node) → T? -
inherited
-
visitIndexExpression2(
IndexExpression2 node) → T? -
inherited
-
visitIntegerLiteral(
IntegerLiteral node) → T? -
inherited
-
visitInterpolationExpression(
InterpolationExpression node) → T? -
inherited
-
visitInterpolationString(
InterpolationString node) → T? -
inherited
-
visitInvalidExpressionAssignmentTarget(
InvalidExpressionAssignmentTarget node) → T? -
inherited
-
visitIsExpression(
IsExpression node) → T? -
inherited
-
visitLabel(
Label node) → T? -
inherited
-
visitLabeledStatement(
LabeledStatement node) → T? -
inherited
-
visitLabelReference(
LabelReference node) → T? -
inherited
-
visitLibraryDirective(
LibraryDirective node) → T? -
inherited
-
visitListLiteral(
ListLiteral node) → T? -
inherited
-
visitListPattern(
ListPattern node) → T? -
inherited
-
visitLogicalAnd(
LogicalAnd node) → T? -
inherited
-
visitLogicalAndPattern(
LogicalAndPattern node) → T? -
inherited
-
visitLogicalNot(
LogicalNot node) → T? -
inherited
-
visitLogicalOr(
LogicalOr node) → T? -
inherited
-
visitLogicalOrPattern(
LogicalOrPattern node) → T? -
inherited
-
visitMapLiteralEntry(
MapLiteralEntry node) → T? -
inherited
-
visitMapPattern(
MapPattern node) → T? -
inherited
-
visitMapPatternEntry(
MapPatternEntry node) → T? -
inherited
-
visitMethodDeclaration(
MethodDeclaration node) → T? -
inherited
-
visitMethodDeclaration2(
MethodDeclaration2 node) → T? -
inherited
-
visitMethodInvocation(
MethodInvocation node) → T? -
inherited
-
visitMixinDeclaration(
MixinDeclaration node) → T? -
inherited
-
visitMixinOnClause(
MixinOnClause node) → T? -
inherited
-
visitNamedArgument(
NamedArgument node) → T? -
inherited
-
visitNamedType(
NamedType node) → T? -
inherited
-
visitNameWithTypeParameters(
NameWithTypeParameters node) → T? -
inherited
-
visitNativeClause(
NativeClause node) → T? -
inherited
-
visitNativeFunctionBody(
NativeFunctionBody node) → T? -
inherited
-
visitNode(
AstNode node) → T? -
override
-
visitNullAssertionExpression(
NullAssertionExpression node) → T? -
inherited
-
visitNullAssertPattern(
NullAssertPattern node) → T? -
inherited
-
visitNullAwareElement(
NullAwareElement node) → T? -
inherited
-
visitNullCheckPattern(
NullCheckPattern node) → T? -
inherited
-
visitNullLiteral(
NullLiteral node) → T? -
inherited
-
visitObjectPattern(
ObjectPattern node) → T? -
inherited
-
visitOperatorDeclaration(
OperatorDeclaration node) → T? -
inherited
-
visitParenthesizedExpression(
ParenthesizedExpression node) → T? -
inherited
-
visitParenthesizedPattern(
ParenthesizedPattern node) → T? -
inherited
-
visitPartDirective(
PartDirective node) → T? -
inherited
-
visitPartOfDirective(
PartOfDirective node) → T? -
inherited
-
visitPatternAssignment(
PatternAssignment node) → T? -
inherited
-
visitPatternField(
PatternField node) → T? -
inherited
-
visitPatternFieldName(
PatternFieldName node) → T? -
inherited
-
visitPatternVariableDeclaration(
PatternVariableDeclaration node) → T? -
inherited
-
visitPatternVariableDeclarationStatement(
PatternVariableDeclarationStatement node) → T? -
inherited
-
visitPostfixDecrement(
PostfixDecrement node) → T? -
inherited
-
visitPostfixIncrement(
PostfixIncrement node) → T? -
inherited
-
visitPrefixDecrement(
PrefixDecrement node) → T? -
inherited
-
visitPrefixedIdentifier(
PrefixedIdentifier node) → T? -
inherited
-
visitPrefixIncrement(
PrefixIncrement node) → T? -
inherited
-
visitPrimaryConstructorBody(
PrimaryConstructorBody node) → T? -
inherited
-
visitPrimaryConstructorDeclaration(
PrimaryConstructorDeclaration node) → T? -
inherited
-
visitPrimaryConstructorName(
PrimaryConstructorName node) → T? -
inherited
-
visitPropertyAccess(
PropertyAccess node) → T? -
inherited
-
visitReceiverPropertyAssignmentTarget(
ReceiverPropertyAssignmentTarget node) → T? -
inherited
-
visitReceiverPropertyExtraction(
ReceiverPropertyExtraction node) → T? -
inherited
-
visitRecordLiteral(
RecordLiteral node) → T? -
inherited
-
visitRecordLiteralNamedField(
RecordLiteralNamedField node) → T? -
inherited
-
visitRecordPattern(
RecordPattern node) → T? -
inherited
-
visitRecordTypeAnnotation(
RecordTypeAnnotation node) → T? -
inherited
-
visitRecordTypeAnnotationNamedField(
RecordTypeAnnotationNamedField node) → T? -
inherited
-
visitRecordTypeAnnotationNamedFields(
RecordTypeAnnotationNamedFields node) → T? -
inherited
-
visitRecordTypeAnnotationPositionalField(
RecordTypeAnnotationPositionalField node) → T? -
inherited
-
visitRedirectingConstructorInvocation(
RedirectingConstructorInvocation node) → T? -
inherited
-
visitRegularFormalParameter(
RegularFormalParameter node) → T? -
inherited
-
visitRelationalPattern(
RelationalPattern node) → T? -
inherited
-
visitRestPatternElement(
RestPatternElement node) → T? -
inherited
-
visitRethrowExpression(
RethrowExpression node) → T? -
inherited
-
visitReturnStatement(
ReturnStatement node) → T? -
inherited
-
visitScriptTag(
ScriptTag node) → T? -
inherited
-
visitSetOrMapLiteral(
SetOrMapLiteral node) → T? -
inherited
-
visitSetterDeclaration(
SetterDeclaration node) → T? -
inherited
-
visitShowCombinator(
ShowCombinator node) → T? -
inherited
-
visitSimpleIdentifier(
SimpleIdentifier node) → T? -
inherited
-
visitSimpleStringLiteral(
SimpleStringLiteral node) → T? -
inherited
-
visitSpreadElement(
SpreadElement node) → T? -
inherited
-
visitStringInterpolation(
StringInterpolation node) → T? -
inherited
-
visitSuperConstructorInvocation(
SuperConstructorInvocation node) → T? -
inherited
-
visitSuperExpression(
SuperExpression node) → T? -
inherited
-
visitSuperFormalParameter(
SuperFormalParameter node) → T? -
inherited
-
visitSwitchCase(
SwitchCase node) → T? -
inherited
-
visitSwitchDefault(
SwitchDefault node) → T? -
inherited
-
visitSwitchExpression(
SwitchExpression node) → T? -
inherited
-
visitSwitchExpressionCase(
SwitchExpressionCase node) → T? -
inherited
-
visitSwitchPatternCase(
SwitchPatternCase node) → T? -
inherited
-
visitSwitchStatement(
SwitchStatement node) → T? -
inherited
-
visitSymbolLiteral(
SymbolLiteral node) → T? -
inherited
-
visitThisExpression(
ThisExpression node) → T? -
inherited
-
visitThrowExpression(
ThrowExpression node) → T? -
inherited
-
visitTopLevelGetterDeclaration(
TopLevelGetterDeclaration node) → T? -
inherited
-
visitTopLevelVariableDeclaration(
TopLevelVariableDeclaration node) → T? -
inherited
-
visitTryStatement(
TryStatement node) → T? -
inherited
-
visitTypeArgumentList(
TypeArgumentList node) → T? -
inherited
-
visitTypeLiteral(
TypeLiteral node) → T? -
inherited
-
visitTypeParameter(
TypeParameter node) → T? -
inherited
-
visitTypeParameterList(
TypeParameterList node) → T? -
inherited
-
visitUnaryOperatorInvocation(
UnaryOperatorInvocation node) → T? -
inherited
-
visitUnqualifiedNameAssignmentTarget(
UnqualifiedNameAssignmentTarget node) → T? -
inherited
-
visitVariableDeclaration(
VariableDeclaration node) → T? -
inherited
-
visitVariableDeclarationList(
VariableDeclarationList node) → T? -
inherited
-
visitVariableDeclarationStatement(
VariableDeclarationStatement node) → T? -
inherited
-
visitWhenClause(
WhenClause node) → T? -
inherited
-
visitWhileStatement(
WhileStatement node) → T? -
inherited
-
visitWildcardPattern(
WildcardPattern node) → T? -
inherited
-
visitWithClause(
WithClause node) → T? -
inherited
-
visitYieldStatement(
YieldStatement node) → T? -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited