toTypeValueNotExtensionTypeErased abstract method
Return the static type of the type literal, almost like toTypeValue, but without performing extension type erasure.
Implementation
@experimental
DartType? toTypeValueNotExtensionTypeErased();
Return the static type of the type literal, almost like toTypeValue, but without performing extension type erasure.
@experimental
DartType? toTypeValueNotExtensionTypeErased();