isOriginImplicitDefault property
bool
get
isOriginImplicitDefault
Whether the constructor was created because there are no explicit constructors.
Implementation
bool get isOriginImplicitDefault;
Whether the constructor was created because there are no explicit constructors.
bool get isOriginImplicitDefault;