thisOrAncestorOfType<E extends Element> abstract method
E?
thisOrAncestorOfType<E extends Element>()
Returns either this element or the most immediate ancestor of this element that has the given type.
Returns null if there is no such element.
Implementation
E? thisOrAncestorOfType<E extends Element>();