isValidAtElement abstract method

bool? isValidAtElement(
  1. Element element
)

Whether this annotation is a valid annotation for the given element.

Returns true if the annotation has known target kinds, and the element matches one of them. Returns false if the annotation has known target kinds, and the element does not match any of them.

Returns null if there is no known set of target kinds for this annotation.

Implementation

bool? isValidAtElement(Element element);