isOriginNotExistingFile property
bool
get
isOriginNotExistingFile
Whether the library fragment is created from a file that does not exist.
Implementation
bool get isOriginNotExistingFile;
Whether the library fragment is created from a file that does not exist.
bool get isOriginNotExistingFile;