SetterFragment class abstract

The portion of a SetterElement contributed by a single declaration.

Clients may not extend, implement or mix-in this class.

Implemented types

Constructors

SetterFragment()

Properties

children → List<Fragment>
The children of this fragment.
no setterinherited
documentationComment → String?
The content of the documentation comment (including delimiters) for this fragment.
no setterinherited
element → SetterElement
The element composed from this fragment and possibly other fragments.
no setteroverride
enclosingFragment → Fragment?
The fragment that either physically or logically encloses this fragment.
no setterinherited
formalParameters → List<FormalParameterFragment>
The formal parameters defined by this fragment.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inducingVariable → PropertyInducingFragment?
The field or top-level variable fragment that induced this accessor fragment.
no setterinherited
isAsynchronous → bool
Whether the body is marked as being asynchronous.
no setterinherited
isAugmentation → bool
Whether the element is an augmentation.
no setterinherited
isGenerator → bool
Whether the body is marked as being a generator.
no setterinherited
isSynchronous → bool
Whether the body is marked as being synchronous.
no setterinherited
libraryFragment → LibraryFragment
The library fragment that contains this fragment.
no setterinherited
metadata → Metadata
The metadata associated with the fragment.
no setterinherited
name → String?
The name of the fragment.
no setterinherited
nameOffset → int?
The offset of the name of this element.
no setterinherited
nextFragment → SetterFragment?
The next fragment in the augmentation chain.
no setteroverride
offset → int
The offset of the setter name.
no setteroverride
previousFragment → SetterFragment?
The previous fragment in the augmentation chain.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeParameters → List<TypeParameterFragment>
The type parameters declared by this fragment directly.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited