constantInitializer2 property
The constant initializer for this constant variable, or the default value for this formal parameter.
Is null if this variable is not a constant, or does not have the
initializer or the default value specified.
Implementation
@experimental
Expression? get constantInitializer2;