nullabilitySuffix property
NullabilitySuffix
get
nullabilitySuffix
The nullability suffix with which the element was instantiated.
Implementation
NullabilitySuffix get nullabilitySuffix;
The nullability suffix with which the element was instantiated.
NullabilitySuffix get nullabilitySuffix;