DiagnosticType class

The type of a DiagnosticCode.

Implemented types
Annotations
  • @AnalyzerPublicApi.new(message: 'exported by package:analyzer/error/error.dart')

Constructors

DiagnosticType(String name, int ordinal, DiagnosticSeverity severity)
Initialize a newly created error type to have the given name and severity.
const

Properties

displayName → String
no setter
hashCode → int
The hash code for this object.
no setteroverride
name → String
The name of this error type.
final
ordinal → int
The ordinal value of the error type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → DiagnosticSeverity
The severity of this type of error.
final

Methods

compareTo(DiagnosticType other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

CHECKED_MODE_COMPILE_TIME_ERROR → const DiagnosticType
Checked mode compile-time errors are errors that preclude execution in checked mode.
COMPILE_TIME_ERROR → const DiagnosticType
Compile-time errors are errors that preclude execution. A compile time error must be reported by a Dart compiler before the erroneous code is executed.
HINT → const DiagnosticType
Extra analysis run over the code to follow best practices, which are not in the Dart Language Specification.
LINT → const DiagnosticType
Lint warnings describe style and best practice recommendations that can be used to formalize a project's style guidelines.
STATIC_WARNING → const DiagnosticType
Static warnings are those warnings reported by the static checker. They have no effect on execution. Static warnings must be provided by Dart compilers used during development.
SYNTACTIC_ERROR → const DiagnosticType
Syntactic errors are errors produced as a result of input that does not conform to the grammar.
TODO → const DiagnosticType
Task (todo) comments in user code.
values → const List<DiagnosticType>