getChildAssumingFile abstract method
Return a File representing a child at the given relPath.
This call does not check whether a file exists at the given path; clients
must call the File's exists getter to determine whether the file
actually exists. If a folder exists at the path, the returned File's
exists getter returns false.
Implementation
@Deprecated('Use getFile instead.')
File getChildAssumingFile(String relPath);