getFolder abstract method
Return a Folder representing a child at the given relPath.
This call does not check whether a folder exists at the given path;
clients must call the Folder's exists getter to determine whether the
folder actually exists. If a file exists at the path, the returned
Folder's exists getter returns false.
Implementation
Folder getFolder(String relPath);