optionsFile property
File?
get
optionsFile
The analysis options file that applies at the root, or null if there
is no such options file.
Files nested within this context root can use other options files. Use
AnalysisContext.getAnalysisOptionsForFile to obtain the options for a
specific file.
Implementation
File? get optionsFile;