getFragmentDeclaration2 abstract method
Returns the declaration of the fragment in the V2 AST view.
Returns null if the fragment is synthetic.
Throws ArgumentError if the fragment is not defined in this library.
Implementation
@experimental
FragmentDeclarationResult? getFragmentDeclaration2(Fragment fragment);