realTarget property
The expression used to compute the receiver of the invocation.
If this invocation isn't part of a cascade expression, then this is the same as target. If this invocation is part of a cascade expression, then the target stored with the cascade expression is returned.
Implementation
@ToBeDeprecated('Use realTarget2 instead.')
Expression get realTarget;