hasRead property
bool
get
hasRead
Whether the enclosing operation reads the target's current value before writing a new value.
This is determined by the syntax of the enclosing operation and doesn't depend on whether this target has been resolved successfully.
Implementation
bool get hasRead;