read property
IndexReadResolution?
get
read
The read operation, or null if the enclosing operation does not read,
this target has not been resolved, or the cascade target cannot complete.
Implementation
IndexReadResolution? get read;