The element exported under name, or null if there is no such element.
null
This is the element in the ordinary namespace entry, which includes getters, functions, variables, classes, mixins, and type aliases.
Element? get element;