lookupThisType abstract method
Queries the type of this at the given offset.
The offset is relative to the beginning of the source file, but must refer to a location within the function body in order for the response to be accurate.
The bodies of local functions and function literals cannot be queried directly; the query must be made using the enclosing non-local function body.
Returns null if:
- resolution has not been performed,
- the query is made on the body of a local function or function literal,
- or
thisis not meaningful at the given offset.
Implementation
@experimental
DartType? lookupThisType({required int offset});