typeArgumentTypes property
The effective type arguments used to instantiate operand.
For valid code, these are the resolved types of typeArguments. If the
number of written arguments is incorrect, resolution reports an error and
uses dynamic for every type parameter so that analysis can continue with
an instantiated function type. For example, f<int> for a function with
two type parameters has effective arguments [dynamic, dynamic], while
typeArguments still contains only the written int.
Null if no function instantiation was resolved, for example because operand does not have a function type.
Implementation
List<DartType>? get typeArgumentTypes;