read property
IndexReadResolution?
get
read
The read operation, or null if the enclosing operation does not read,
this target has not been resolved, or receiver evaluation prevents the
index operation.
Implementation
IndexReadResolution? get read;