target property
The expression used to compute the object being indexed, or null if this
index expression is part of a cascade expression.
Use realTarget to get the target independent of whether this is part of a cascade expression.
Implementation
@ToBeDeprecated('Use target2 instead.')
Expression? get target;