parseIntValue abstract method
Returns the int value represented by this literal, or null if the
value can't be represented as an int.
If negated is true, parses the expression formed by immediately
preceding this literal with a unary minus. This allows the minimum int
value to be represented even though its positive magnitude can't be.
Implementation
int? parseIntValue({required bool negated});