A named read that was resolved to an element.
Concrete subtypes describe how the name is read, such as by directly reading a local variable or formal parameter, or by invoking a getter.
- Implemented types
- Implementers
- Annotations
-
- @experimental
- @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')
Properties
- element → Element
-
The selected declaration, including any substitution for this occurrence,
or
nullif the read does not select a declaration.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DartType
-
The static type of the value produced if the read executes.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited