isComplete property
bool
get
isComplete
Whether this primary constructor declaration is complete for augmentation purposes.
A primary constructor declaration is complete if it has a body, has an initializer list, or has a declaring formal, field formal, super formal, or extension type representation formal parameter.
Implementation
bool get isComplete;