read property
NamedReadResolution?
get
read
The read operation, or null if the assignment does not read the target,
this target has not been resolved, or receiver evaluation prevents the
access.
Implementation
NamedReadResolution? get read;