period property
The token for the period before the name of the constructor that is being
invoked, or null if the unnamed constructor is being invoked.
Implementation
@ToBeDeprecated('Use constructorSelector instead.')
Token? get period;
The token for the period before the name of the constructor that is being
invoked, or null if the unnamed constructor is being invoked.
@ToBeDeprecated('Use constructorSelector instead.')
Token? get period;