constructorName property
The name of the constructor that is being invoked, or null if the
unnamed constructor is being invoked.
Implementation
@ToBeDeprecated('Use constructorSelector instead.')
SimpleIdentifier? get constructorName;
The name of the constructor that is being invoked, or null if the
unnamed constructor is being invoked.
@ToBeDeprecated('Use constructorSelector instead.')
SimpleIdentifier? get constructorName;