The resolution of a write operation.
Named and indexed writes share this interface. Concrete subtypes describe how the value is stored or which setter or index operator is invoked.
- Implementers
- Annotations
-
- @experimental
- @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')
Properties
- acceptedType → DartType
-
The type accepted by the write operation.
no setter
- element → Element?
-
The selected declaration, including any substitution for this occurrence,
or
nullif the write does not select a declaration.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited