inducedGetter property
GetterFragment?
get
inducedGetter
The getter fragment induced by this variable or field fragment.
Returns null for synthetic variable or field fragments created for
explicit accessor declarations. Such fragments do not induce accessors;
instead, they are created because explicit accessors need an associated
property-inducing element.
Implementation
GetterFragment? get inducedGetter;